@@ -41,7 +41,10 @@ def to_shopify_book(payload: dict) -> ShopifyBook:
         return None
 
     try:
-        metafields = payload["metafields"]["edges"]
+        try:
+            metafields = payload["metafields"]["edges"]
+        except KeyError:
+            metafields = payload["metafields"]
         variant = payload["variants"]["edges"][0]["node"]
         return ShopifyBook(
             gid=payload["id"],
