@@ -3,11 +3,10 @@ from __future__ import annotations
 import abc
 from decimal import Decimal
 from enum import Enum
-from typing import Optional
 
 from pydantic import BaseModel, validator
 
-from src.validators import is_valid_isbn, is_valid_url, sanitize_isbn
+from .validators import is_valid_isbn, is_valid_url, sanitize_isbn
 
 
 class QuerySchema(BaseModel):
@@ -36,26 +35,34 @@ class ShopifyBook(QuerySchema):
     title: str
     author: str
     price: Decimal
-    subtitle: Optional[str]
-    description: Optional[str]
-    publisher: Optional[str]
-    published_date: Optional[str]
+    subtitle: str | None
+    description: str | None
+    publisher: str | None
+    published_date: str | None
 
     @property
     def id(self) -> int:
         return int(self.gid.split("/")[-1])
 
 
+class ProductType(Enum):
+    book = "Books"
+    textbook = "Textbook"
+
+
 class CreateBookInput(MutationSchema):
     isbn: str
     title: str
     author: str
     price: Decimal
-    subtitle: Optional[str] = None
-    description: Optional[str] = None
-    publisher: Optional[str] = None
-    published_date: Optional[str] = None
-    cover_image: Optional[str] = None
+    product_type: str = "Textbook"
+    subtitle: str | None = None
+    description: str | None = None
+    publisher: str | None = None
+    published_date: str | None = None
+    cover_image: str | None = None
+    staff_comment: str | None = None
+    tags: list[str] = []
 
     @validator("isbn")
     def isbn_must_be_10_or_13_digits(cls, v):
@@ -76,7 +83,8 @@ class CreateBookInput(MutationSchema):
             "title": self.title,
             "vendor": self.publisher,
             "descriptionHtml": self.description,
-            "productType": "Book",
+            "productType": self.product_type,
+            "tags": self.tags,
             "variants": [
                 {
                     "sku": self.isbn,
@@ -95,6 +103,11 @@ class CreateBookInput(MutationSchema):
                     "namespace": "book",
                     "value": self.published_date,
                 },
+                {
+                    "key": "staff_comment",
+                    "namespace": "book",
+                    "value": self.staff_comment,
+                },
             ],
         }
         if self.cover_image:
@@ -104,13 +117,13 @@ class CreateBookInput(MutationSchema):
 
 class UpdateBookInput(MutationSchema):
     product_id: int
-    isbn: Optional[str] = None
-    title: Optional[str] = None
-    author: Optional[str] = None
-    subtitle: Optional[str] = None
-    description: Optional[str] = None
-    publisher: Optional[str] = None
-    published_date: Optional[str] = None
+    isbn: str | None = None
+    title: str | None = None
+    author: str | None = None
+    subtitle: str | None = None
+    description: str | None = None
+    publisher: str | None = None
+    published_date: str | None = None
 
     @validator("isbn")
     def isbn_must_be_10_or_13_digits(cls, v):
@@ -126,7 +139,7 @@ class MetafieldDefinition(QuerySchema):
     key: str
     name: str
     namespace: str
-    description: Optional[str]
+    description: str | None
 
     @property
     def id(self) -> int:
